@@ -38,6 +38,7 @@
 
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <endian.h>
 #include <fcntl.h>
 #include <string>
 #include <unistd.h>
@@ -90,25 +91,26 @@ namespace lsvpd
 	 * Uses the highest preference Source to fill this DataItem
 	 */
 	void DeviceTreeCollector::readSources( DataItem& di,
-		const string& devTreeNode )
+					       const string& devTreeNode )
 	{
 		const Source * s = di.getFirstSource( );
 		if( s != NULL && s ->getType( ) == SRC_DEVICETREE )
 		{
 			string val = getAttrValue( devTreeNode, s->getData( ) );
 			if( val != "" )
-				di.setValue( val, s->getPrefLvl( ), __FILE__, __LINE__ );
+				di.setValue( val, s->getPrefLvl( ), __FILE__,
+								__LINE__ );
 		}
 		return;
 	}
 
 	void DeviceTreeCollector::initComponent( Component * newComp )
 	{
-			Source *src = new Source("ibm,fw-adapter-name", "",
-				 SRC_DEVICETREE, ASCII, 1, 3);
-			newComp->mDescription.setHumanName("Description");
-			newComp->mDescription.setAC("DS");
-			newComp->mDescription.addSource(src);
+		Source *src = new Source("ibm,fw-adapter-name", "",
+					 SRC_DEVICETREE, ASCII, 1, 3);
+		newComp->mDescription.setHumanName("Description");
+		newComp->mDescription.setAC("DS");
+		newComp->mDescription.addSource(src);
 	}
 
 	Component* DeviceTreeCollector::fillComponent(Component* fillMe )
@@ -132,7 +134,7 @@ namespace lsvpd
 	 * with code=code2.
 	 */
 	string collectEitherSystemParm(int code1,
-		int code2)
+				       int code2)
 	{
 
 		string s = RtasCollector::rtasSystemParm(code1);
@@ -160,17 +162,23 @@ namespace lsvpd
 	 * output for new Components, fill the new Components with the VPD
 	 * provided and add the new Components to the Component vector.
 	 */
-	void DeviceTreeCollector::parseRtasVpd( vector<Component*>& devs,
-		char *rtasData, int rtasDataSize)
+	void DeviceTreeCollector::parseRtasVpd(vector<Component*>& devs,
+					       char *rtasData,
+					       unsigned long int rtasDataSize)
 	{
-		unsigned int size = 0;
+		unsigned long int size = 0;
 		unsigned int ret = 1;
 
-		if( rtasData == NULL || rtasDataSize <= 0 )
+		if( rtasData == NULL || (long int)rtasDataSize <= 0 )
 			return;
-		while( size < rtasDataSize && ret > 0 )
+
+		while( ((long int) size < (long int) rtasDataSize)
+		       && (int) ret > 0 )
 		{
 			Component* c = new Component( );
+			if ( c == NULL )
+				return;
+
 			ret = parseVPDBuffer( c, rtasData );
 			if( ret == 0 )
 			{
@@ -189,7 +197,7 @@ namespace lsvpd
 			}
 
 			/*
-			 * Build a uniquie device ID and deviceTreeNode
+			 * Build a unique device ID and deviceTreeNode
 			 */
 			ostringstream os;
 			os << "/proc/device-tree/rtas/"  << c->getPhysicalLocation( );
@@ -205,7 +213,7 @@ namespace lsvpd
 	bool DeviceTreeCollector::fillQuickVPD(Component * fillMe)
 	{
 		string val, path, path_tmp;
-		int done = 0, i;
+		int i;
 
 		/* Grab an easy AIX Name, higher quality than the base AIX */
 		val = getAttrValue( fillMe->deviceTreeNode.dataValue, "name" );
@@ -223,7 +231,8 @@ namespace lsvpd
 
 		val = getAttrValue( fillMe->deviceTreeNode.dataValue, "fru-type" );
 		if (val.length() > 0)
-			fillMe->mDescription.setValue( getFruDescription(val), 90, __FILE__, __LINE__ );
+			fillMe->mDescription.setValue( getFruDescription(val),
+						       90, __FILE__, __LINE__ );
 
 		/* Loc code */
 		/* bpeters: Many storage devices sit on a port of an adapter, and are not
@@ -234,7 +243,8 @@ namespace lsvpd
 		path = fillMe->deviceTreeNode.dataValue;
 		val = getAttrValue( path, "ibm,loc-code" );
 		if (val.length() > 0) {
-			fillMe->mPhysicalLocation.setValue( val, 90, __FILE__, __LINE__ );
+			fillMe->mPhysicalLocation.setValue( val, 90, __FILE__,
+							    __LINE__ );
 			return true;
 		}
 		else { /* walk up device path until loc-code found */
@@ -244,7 +254,8 @@ namespace lsvpd
 				path = path_tmp.substr(0, i);
 				val = getAttrValue( path, "ibm,loc-code" );
 				if (val.length() > 0) {
-					fillMe->mPhysicalLocation.setValue( val, 90, __FILE__, __LINE__ );
+					fillMe->mPhysicalLocation.setValue( val,
+						90, __FILE__, __LINE__ );
 					return true;
 				}
 
@@ -273,7 +284,7 @@ namespace lsvpd
 		fillMe->mDescription.setValue( val, 25, __FILE__, __LINE__ );
 
 		val = getAttrValue( fillMe->deviceTreeNode.dataValue,
-			 "ibm,fw-adapter-name" );
+				    "ibm,fw-adapter-name" );
 		if( val != "" )
 		{
 			ostringstream os;
@@ -286,7 +297,8 @@ namespace lsvpd
 				os << val;
 				val = os.str( );
 			}
-			fillMe->mDescription.setValue( val, 60, __FILE__, __LINE__ );
+			fillMe->mDescription.setValue( val, 60, __FILE__,
+								__LINE__ );
 		}
 	}
 
@@ -315,8 +327,8 @@ namespace lsvpd
 	 * @fruName : Ptr to the name of the section if available.
 	 * @recordStart : Ptr in buf, where the records start.
 	 */
-	static unsigned int parseRtasVPDHeader( char *buf,
-					char **fruName, char **recordStart )
+	static unsigned int parseRtasVPDHeader( char *buf, char **fruName,
+						char **recordStart )
 	{
 		char *ptr, *dataEnd;
 		u32 size;
@@ -339,6 +351,8 @@ namespace lsvpd
 		if (ptr + dlen > dataEnd)
 			goto error;
 		*fruName = new char [ dlen + 1 ];
+		if ( *fruName == NULL )
+			goto error;
 		memset(*fruName, 0, dlen + 1);
 		memcpy(*fruName, ptr, dlen);
 
@@ -349,7 +363,7 @@ namespace lsvpd
 error:
 		Logger log;
 		log.log("Attempting to parse unsupported/corrupted VPD header",
-						LOG_WARNING);
+			LOG_WARNING);
 		return 0;
 	}
 
@@ -360,8 +374,8 @@ error:
 	 * 		in the OPAL VPD
 	 * @recordStart : Pointer to the area where the records start.
 	 */
-	static unsigned int parseOpalVPDHeader( char *buf,
-					char **fruName, char **recordStart)
+	static unsigned int parseOpalVPDHeader( char *buf, char **fruName,
+						char **recordStart)
 	{
 		char type;
 		unsigned int size = 0;
@@ -375,6 +389,9 @@ error:
 		size = *buf++;
 		size |= (*buf++) << 8;
 
+		/* Convert to host format */
+		size = be16toh(size);
+
 		/* Records start here */
 		*recordStart = buf;
 
@@ -389,12 +406,21 @@ error:
 	}
 
 	unsigned int DeviceTreeCollector::parseVPDHeader( char *buf,
-								char **fruName, char **recordStart )
+							  char **fruName,
+							  char **recordStart )
 	{
 		if (isPlatformRTAS())
 			return parseRtasVPDHeader(buf, fruName, recordStart);
 		else if (isPlatformOPAL())
 			return parseOpalVPDHeader(buf, fruName, recordStart);
+		else {
+			Logger log;
+			ostringstream os;
+			os << "Unsupported platform ";
+			log.log(os.str(), LOG_WARNING);
+
+			return -1;
+		}
 	}
 
 	/**
@@ -402,7 +428,7 @@ error:
 	 * setVPDField
 	 */
 	unsigned int DeviceTreeCollector::parseVPDBuffer( Component* fillMe,
-		char * buf )
+							  char * buf )
 	{
 		u32 size;
 		char key[ 3 ] = { '\0' };
@@ -418,7 +444,7 @@ error:
 
 		if (fruName) {
 			fillMe->mDescription.setValue(string(fruName), 80,
-							__FILE__, __LINE__);
+						      __FILE__, __LINE__);
 			delete [] fruName;
 		}
 
@@ -497,48 +523,48 @@ ERROR:
 		i = str.length();
 		while (ok) {
 			switch (str[i]) {
-				case '\0':;
-				case '0':;
-				case '1':;
-				case '2':;
-				case '3':;
-				case '4':;
-				case '5':;
-				case '6':;
-				case '7':;
-				case '8':;
-				case '9':;
-				case 'a':;
-				case 'b':;
-				case 'c':;
-				case 'd':;
-				case 'e':;
-				case 'f':;
-				case 'g':;
-				case 'h':;
-				case 'i':;
-				case 'j':;
-				case 'k':;
-				case 'l':;
-				case 'm':;
-				case 'n':;
-				case 'o':;
-				case 'p':;
-				case 'q':;
-				case 'r':;
-				case 's':;
-				case 't':;
-				case 'u':;
-				case 'v':;
-				case 'w':;
-				case 'x':;
-				case 'y':;
-				case 'z':;
-				case ',':;
-				case ':':
-							i--;
-							break;
-				default : ok = false;
+			case '\0':;
+			case '0':;
+			case '1':;
+			case '2':;
+			case '3':;
+			case '4':;
+			case '5':;
+			case '6':;
+			case '7':;
+			case '8':;
+			case '9':;
+			case 'a':;
+			case 'b':;
+			case 'c':;
+			case 'd':;
+			case 'e':;
+			case 'f':;
+			case 'g':;
+			case 'h':;
+			case 'i':;
+			case 'j':;
+			case 'k':;
+			case 'l':;
+			case 'm':;
+			case 'n':;
+			case 'o':;
+			case 'p':;
+			case 'q':;
+			case 'r':;
+			case 's':;
+			case 't':;
+			case 'u':;
+			case 'v':;
+			case 'w':;
+			case 'x':;
+			case 'y':;
+			case 'z':;
+			case ',':;
+			case ':':
+				 i--;
+				 break;
+			default : ok = false;
 			}
 		}
 		if (str[i] == '@')
@@ -554,9 +580,10 @@ ERROR:
 	 * @return the specified component, or NULL on failure
 	 */
 	Component *DeviceTreeCollector::findComponent(
-		const vector<Component*> devs, string devPath )
+						      const vector<Component*> devs,
+						      string devPath )
 	{
-		for (int i = 0; i < devs.size(); i++)
+		for (int i = 0; i < (int) devs.size(); i++)
 			if (devs[i]->deviceTreeNode.getValue() == devPath)
 				return devs[i];
 
@@ -569,7 +596,8 @@ ERROR:
 	 * @return the specified component, or NULL on failure
 	 */
 	Component *DeviceTreeCollector::findCompIdNode(
-		vector<Component*> *devs, const string id )
+						       vector<Component*> *devs,
+						       const string id )
 	{
 		vector<Component*>::iterator i, end;
 
@@ -593,11 +621,12 @@ ERROR:
 		vector<string>::iterator vi, vend;
 
 		dest->deviceTreeNode.setValue(src->deviceTreeNode.getValue(), 100,
-												__FILE__, __LINE__);
+					      __FILE__, __LINE__);
 		dest->devDevTreeName.setValue(src->devDevTreeName.getValue(), 100,
-												__FILE__, __LINE__);
+					      __FILE__, __LINE__);
 		dest->devType.setValue(src->devType.getValue(),
-			src->devType.getPrefLevelUsed(), __FILE__, __LINE__);
+				       src->devType.getPrefLevelUsed(), __FILE__,
+				       __LINE__);
 
 		/* Copy children */
 		for ( vi = kids.begin( ), vend = kids.end( ); vi != vend; ++vi ) {
@@ -609,23 +638,23 @@ ERROR:
 	/*
 	 * transferChildren
 	 * @brief When a component is discovered in device tree collector,
-	 * 	then moved into the full device vector, this method handles
-	 * 	moving over the children (recursively) of the moved component
+	 *	then moved into the full device vector, this method handles
+	 *	moving over the children (recursively) of the moved component
 	 * @arg parentSrc - The parent component from the src tree
 	 * @arg defaultParent - The parent of top level components,
-	 * 	in this case, defined as those who's parents are
-	 * 	"/proc/device-tree"
+	 *	in this case, defined as those who's parents are
+	 *	"/proc/device-tree"
 	 * @arg target - The collection into which the children should
-	 * 	be moved
+	 *	be moved
 	 * @arg src - Collection from which the children are being moved.
-	 * 	Note, this collection is unchanged, components are simply
-	 * 	copied.
+	 *	Note, this collection is unchanged, components are simply
+	 *	copied.
 	 */
 
-	 /* transferChildren(&devRoot, sysRoot, &sysdevs, &devs); */
+	/* transferChildren(&devRoot, sysRoot, &sysdevs, &devs); */
 	void DeviceTreeCollector::transferChildren(Component *current,
-			vector<Component*> *target,
-			vector<Component*> *src)
+						   vector<Component*> *target,
+						   vector<Component*> *src)
 	{
 		vector<string> kids = current->getChildren( );
 		vector<string>::iterator vi, vend;
@@ -635,7 +664,7 @@ ERROR:
 			for ( i = src->begin( ), end = src->end( ); i != end; ++i ) {
 				if ( (*i)->idNode.getValue() == *vi) {
 					target->push_back(*i);
-//					src->erase(i);
+					//					src->erase(i);
 					/*Recurse*/
 					transferChildren(*i, target, src);
 				}
@@ -644,9 +673,9 @@ ERROR:
 	}
 
 	void DeviceTreeCollector::mergeTrees(Component *current,
-			Component *defaultParent,
-			vector<Component*> *target,
-			vector<Component*> *src)
+					     Component *defaultParent,
+					     vector<Component*> *target,
+					     vector<Component*> *src)
 	{
 		vector<string> kids = current->getChildren( );
 		vector<string>::iterator vi, vend;
@@ -670,20 +699,22 @@ ERROR:
 			transferChildren(current, target, src);
 
 			cpyinto(current->devSelfInSysfs, current);
-			parent = findCompIdNode(target, current->devSelfInSysfs->mParent.dataValue);
+			parent = findCompIdNode(target,
+						current->devSelfInSysfs->mParent.dataValue);
+
 			/* Update childs mParent pointer -
 			 * Note: The parent does not require a child ptr, since merged
 			 *  and already present */
 
 			current->mParent.setValue(
-					parent->idNode.dataValue,
-					90, __FILE__, __LINE__);
+						  parent->idNode.dataValue,
+						  90, __FILE__, __LINE__);
 
 		}
 		/* Convert top-level devices to point to defaultParent*/
 		else if (current->mParent.dataValue == DEVTREEPATH) {
 			current->mParent.setValue(defaultParent->idNode.dataValue,
-				 80, __FILE__, __LINE__);
+						  80, __FILE__, __LINE__);
 			defaultParent->addChild(current->idNode.dataValue);
 			target->push_back(current);
 			/* Recursively transfer all children of this node to new tree */
@@ -692,14 +723,14 @@ ERROR:
 	}
 
 	/* @brief Determine the parent of this device, using a bus-specific
-	 * 	search mechanism.  SCSI specific at this point, but some of this
-	 * 	may be generalizable and expanded for application to usb and ide
-	 * 	buses in future versions
+	 *	search mechanism.  SCSI specific at this point, but some of this
+	 *	may be generalizable and expanded for application to usb and ide
+	 *	buses in future versions
 	 *
 	 * @param devs - /sys & /proc/device-tree Merged tree of devices
 	 */
 	Component * DeviceTreeCollector::findSCSIParent(Component *fillMe,
-										vector<Component*> devs)
+							vector<Component*> devs)
 	{
 		string sysDev, devPath;
 		string parentSysFsName, pYL;
@@ -710,12 +741,12 @@ ERROR:
 		devSpecific = fillMe->getDeviceSpecific("XB");
 		if (devSpecific != NULL) {
 			parentSysFsName = fillMe->devBus.dataValue
-									+ string("@")
-									+ devSpecific->dataValue;
+				+ string("@")
+				+ devSpecific->dataValue;
 
 			sysDev = fillMe->sysFsLinkTarget.dataValue;
 			while (sysDev.length() > 1) {
-				if ((loc = sysDev.rfind("/", sysDev.length())) != string::npos )
+				if ((loc = sysDev.rfind("/", sysDev.length())) != (int) string::npos )
 					sysDev = sysDev.substr(0, loc);
 
 				for( i = devs.begin( ), end = devs.end( ); i != end; ++i ) {
@@ -734,19 +765,19 @@ ERROR:
 	 * @arg devs - device tree discovered devices
 	 *
 	 * TODO: Need to move Bus parsing for devices to before this step,
-	 * 	so we can test if bus == scsi, ide, usb, and ONLY do this extra
-	 * 	step for these device types
+	 *	so we can test if bus == scsi, ide, usb, and ONLY do this extra
+	 *	step for these device types
 	 */
 	void DeviceTreeCollector::buildSCSILocCode(Component *fillMe,
-											vector<Component*> devs)
+						   vector<Component*> devs)
 	{
 		Component *parent;
 		ostringstream val;
 		const DataItem *target, *lun, *bus;
 
 		/* Build up a distinct YL based on parents YL - for device such as
-		 * 	scsi, ide, usb, etc that do not generate ibm,loc-code
-		 * 	files for easy grabbing
+		 *	scsi, ide, usb, etc that do not generate ibm,loc-code
+		 *	files for easy grabbing
 		 */
 		if (fillMe->devBus.dataValue == "scsi") {
 			parent = findSCSIParent(fillMe, devs);
@@ -759,15 +790,15 @@ ERROR:
 					if (fillMe->mPhysicalLocation.dataValue != "")
 						val << fillMe->mPhysicalLocation.dataValue;
 					else if
-					(parent->mPhysicalLocation.dataValue != "")
-						val << parent->mPhysicalLocation.dataValue;
+						(parent->mPhysicalLocation.dataValue != "")
+							val << parent->mPhysicalLocation.dataValue;
 					else
 						val << getAttrValue( parent->deviceTreeNode.dataValue,
-											 "ibm,loc-code" );
+								     "ibm,loc-code" );
 					val << "-B" << bus->dataValue << "-T" << target->dataValue
 						<< "-L" << lun->dataValue;
 					fillMe->mPhysicalLocation.setValue( val.str( ), 60 ,
-						__FILE__, __LINE__ );
+									    __FILE__, __LINE__ );
 				}
 			}
 		}
@@ -777,6 +808,8 @@ ERROR:
 	{
 		/* Grab system params from rtas, N5 and N6 */
 		Component* c = new Component( );
+		if ( c == NULL )
+			return;
 		/*
 		 * Build a unique device ID and deviceTreeNode for the system params
 		 */
@@ -792,7 +825,7 @@ ERROR:
 
 	void DeviceTreeCollector::getRtasVPD(vector<Component*>& devs)
 	{
-		int bufSize;
+		unsigned long int bufSize;
 		char *rtasData = NULL;
 
 		bufSize = RtasCollector::rtasGetVPD("", &rtasData);
@@ -813,6 +846,8 @@ ERROR:
 	{
 		ostringstream os;
 		Component *c = new Component();
+		if ( c == NULL )
+			return;
 		string val;
 
 		os << OPAL_SYS_FW_DIR;
@@ -829,11 +864,17 @@ ERROR:
 		if (val.length() > 0)
 			setVPDField( c, string("MI"), val.substr(3), __FILE__, __LINE__ );
 
-		val = getAttrValue( os.str( ), OPAL_SYS_FW_CL_FILE );
+		val = getAttrValue( os.str( ), OPAL_SYS_FW_CL_FILE2 );
 		if (val.length() > 0) {
-			string firmware = PlatformCollector::getFirmwareName();
-			val = firmware + " " + val;
+			val = "OPAL " + val;
 			setVPDField( c, string("CL"), val, __FILE__, __LINE__ );
+		} else {
+			val = getAttrValue( os.str( ), OPAL_SYS_FW_CL_FILE );
+			if (val.length() > 0) {
+				string firmware = PlatformCollector::getFirmwareName();
+				val = firmware + " " + val;
+				setVPDField( c, string("CL"), val, __FILE__, __LINE__ );
+			}
 		}
 
 		devs.push_back( c );
@@ -859,11 +900,11 @@ ERROR:
 	 *
 	 * @arg sysdevs: Devices discovered through sysfstreecollector
 	 * @return: A fully merged tree of devices, with a single
-	 * 		root device and some path of inheritance to all
-	 * 		children
+	 *		root device and some path of inheritance to all
+	 *		children
 	 */
 	vector<Component*> DeviceTreeCollector::getComponents(
-		vector<Component*>& sysdevs )
+							      vector<Component*>& sysdevs )
 	{
 		vector<Component*> devs;
 		vector<Component*>::iterator i, end;
@@ -888,7 +929,7 @@ ERROR:
 
 				if (NULL != parent) {
 					child->mParent.setValue(parent->idNode.dataValue, 80,
-													__FILE__, __LINE__);
+								__FILE__, __LINE__);
 					parent->addChild(child->idNode.dataValue);
 					break;
 				}
@@ -896,7 +937,7 @@ ERROR:
 
 			if (parent == NULL) {
 				child->mParent.setValue(DEVTREEPATH, 60,
-													__FILE__, __LINE__);
+							__FILE__, __LINE__);
 				devRoot.addChild(child->idNode.dataValue);
 			}
 		}
@@ -932,7 +973,7 @@ ERROR:
 			 * so parent loc-codes are always going to be obtained if present
 			 */
 			fillQuickVPD( devC );
-				// Deprecated behavior: Otherwise, build one from parent
+			// Deprecated behavior: Otherwise, build one from parent
 			if (devC->devBus.dataValue == "scsi") {
 				buildSCSILocCode(devC, sysdevs);
 			}
@@ -945,8 +986,8 @@ ERROR:
 	 * to list list.  Must call fillComponent on these to obtain full
 	 * details
 	 */
-	vector<Component*> DeviceTreeCollector::getComponentsVector(
-		vector<Component*>& devs )
+	void DeviceTreeCollector::getComponentsVector(
+						      vector<Component*>& devs )
 	{
 		vector<string> curList;
 		vector<string> fullList;
@@ -955,7 +996,6 @@ ERROR:
 		string curPath, tmpDirName, devType;
 		Component *tmp;
 		FSWalk fsw = FSWalk();
-		bool dev;
 
 		fullList.push_back(rootDir); //Start at top of device tree
 
@@ -970,57 +1010,57 @@ ERROR:
 
 			while (curList.size() > 0) {
 				tmpDirName = curList.back();
-				dev = false;
 
 				if (isDevice(tmpDirName)) {
 					// Create new component
 					tmp = new Component();
+					if (  tmp == NULL )
+						return;
 					/*
 					 * Set identifying node (idNode) to dev-tree entry if
 					 * sysfs did not previously set it *
 					 */
 					if (tmp->deviceTreeNode.dataValue.length() == 0) {
 						tmp->idNode.setValue(curPath  + "/" + tmpDirName,
-							INIT_PREF_LEVEL - 1, __FILE__, __LINE__);
+								     INIT_PREF_LEVEL - 1, __FILE__, __LINE__);
 					}
 
 					tmp->deviceTreeNode.setValue(curPath  + "/" + tmpDirName,
-						INIT_PREF_LEVEL, __FILE__, __LINE__);
+								     INIT_PREF_LEVEL, __FILE__, __LINE__);
 
 					// Set what we know of name - ie - directory entry
 					// Set immediately available data fields
 					tmp->devDevTreeName.setValue(tmpDirName, INIT_PREF_LEVEL,
-															__FILE__, __LINE__);
+								     __FILE__, __LINE__);
 
 					devType = getAttrValue(tmp->idNode.dataValue,
-						"device_type");
+							       "device_type");
 					tmp->devType.setValue(devType, 60, __FILE__, __LINE__);
 					/*
 					 * Do not add if this is a memory device. These are
 					 * discovered through rtas
 					 */
 					if (tmp->devDevTreeName.dataValue.substr(0, 6) !=
-						"memory")
+					    "memory")
 						devs.push_back(tmp);
 
 					/* default parent is top object.
 					 * This will be overwritten as more detailed info becomes
 					 * available */
 					tmp->mParent.setValue("/proc/device-tree",
-						 INIT_PREF_LEVEL, __FILE__, __LINE__);
+							      INIT_PREF_LEVEL, __FILE__, __LINE__);
 
-					dev = true;
 					// Push all dirs into fullList for future walking
 					fullList.push_back(curPath + "/" + tmpDirName);
 				}
 
 				curList.pop_back();
 			}
-		fullListFrontNode++;
+			fullListFrontNode++;
 			processed++;
 		}
 
-		return devs;
+		return;
 	}
 
 	int DeviceTreeCollector::numDevicesInTree(void)
@@ -1068,7 +1108,7 @@ ERROR:
 		if( val == "" )
 			return;
 		os << "U";
-		while( ( pos = val.find( "-" ) ) != string::npos )
+		while( ( pos = val.find( "-" ) ) != (int) string::npos )
 		{
 			val[ pos ] = '.';
 		}
@@ -1079,7 +1119,7 @@ ERROR:
 
 	void DeviceTreeCollector::getRtasSystemVPD( System *sys )
 	{
-		int size;
+		unsigned long int size;
 		char *rtasVPD = NULL;
 		string loc;
 
@@ -1142,13 +1182,13 @@ ERROR:
 	}
 
 	/* Parses rtas and various system files for system level VPD
-	 */
+	*/
 	void DeviceTreeCollector::fillSystem( System* sys )
 	{
 		string val = "";
 
 		sys->deviceTreeNode.setValue( "/proc/device-tree", 100,
-							__FILE__, __LINE__);
+					      __FILE__, __LINE__);
 
 		sys->mKeywordVersion.setValue( "ipzSeries", 10, __FILE__, __LINE__ );
 
@@ -1174,7 +1214,7 @@ ERROR:
 			if( !val.compare(0, 4, "IBM,") )
 				sys->mSerialNum2.setValue( val.substr( 6 ), 80, __FILE__, __LINE__ );
 			else
-				 sys->mSerialNum2.setValue( val, 80 , __FILE__, __LINE__ );
+				sys->mSerialNum2.setValue( val, 80 , __FILE__, __LINE__ );
 		}
 
 		getSystemVPD(sys);
@@ -1218,7 +1258,7 @@ ERROR:
 	}
 
 	void DeviceTreeCollector::parseMajorMinor( Component* comp, string& major,
-		string& minor )
+						   string& minor )
 	{
 		string addr = comp->devSysName.dataValue;
 		int index;
@@ -1226,7 +1266,7 @@ ERROR:
 		if( comp->devBus.dataValue == "scsi" )
 		{
 			index = addr.find( ':' );
-			if (index == string::npos)
+			if (index == (int) string::npos)
 				return;
 			major = addr.substr( 0, index );
 			index = addr.rfind( ':' );
@@ -1235,13 +1275,13 @@ ERROR:
 		else if( comp->devBus.dataValue == "ide" )
 		{
 			index = addr.find( '.' );
-			if (index == string::npos)
+			if (index == (int) string::npos)
 				return;
 			major = addr.substr( 0, index );
 			minor = addr.substr( index + 1 );
 		}
 		else if( comp->devBus.dataValue == "usb" &&
-			( index = addr.find( ':' ) ) != string::npos )
+			 ( index = addr.find( ':' ) ) != (int) string::npos )
 		{
 			major = addr.substr( 0, index );
 			minor = addr.substr( index + 1 );
@@ -1264,7 +1304,7 @@ ERROR:
 	{
 		ostringstream os;
 		if( comp->mPhysicalLocation.dataValue != "" &&
-			comp->mPhysicalLocation.dataValue[ 0 ] == 'U' )
+		    comp->mPhysicalLocation.dataValue[ 0 ] == 'U' )
 			return true;
 
 		/*
@@ -1272,8 +1312,8 @@ ERROR:
 		 * better one
 		 */
 
-		 if( comp->mpParent == NULL )
-		 	return false;
+		if( comp->mpParent == NULL )
+			return false;
 
 		string baseLoc = getBaseLoc( comp->mpParent );
 
@@ -1286,10 +1326,10 @@ ERROR:
 		 * now to the existing code.
 		 */
 		if (comp->mPhysicalLocation.dataValue != "" &&
-			comp->mPhysicalLocation.dataValue[ 0 ] == '-') {
+		    comp->mPhysicalLocation.dataValue[ 0 ] == '-') {
 			os << baseLoc << comp->mPhysicalLocation.getValue();
 			comp->mPhysicalLocation.setValue( os.str( ), 90, __FILE__,
-				__LINE__ );
+							  __LINE__ );
 			return true;
 		}
 
@@ -1310,7 +1350,7 @@ ERROR:
 		}
 
 		comp->mPhysicalLocation.setValue( os.str( ), 90, __FILE__,
-			__LINE__ );
+						  __LINE__ );
 		return true;
 
 	}
@@ -1330,7 +1370,7 @@ ERROR:
 					val << parent->mPhysicalLocation.dataValue;
 				else
 					val << getAttrValue( parent->deviceTreeNode.dataValue,
-										 "ibm,loc-code" );
+							     "ibm,loc-code" );
 				val << "-D" << comp->mSecondLocation.dataValue;
 				physical = val.str( );
 			}
@@ -1338,15 +1378,15 @@ ERROR:
 			if( physical != "" )
 			{
 				comp->mPhysicalLocation.setValue( physical, 70, __FILE__,
-					__LINE__ );
+								  __LINE__ );
 				comp->mSecondLocation.setValue( logical, 90, __FILE__,
-					__LINE__ );
+								__LINE__ );
 			}
 		}
 
 		vector<Component*>::iterator i, end;
 		for( i = comp->mLeaves.begin( ), end = comp->mLeaves.end( ); i != end;
-			++i )
+		     ++i )
 		{
 			postProcess( (*i) );
 		}
