@@ -13,7 +13,7 @@
 #endif
 
 
-// #define DEBUGRTAS 1 
+// #define DEBUGRTAS 1
 
 #include <libvpd-2/lsvpd_error_codes.hpp>
 #include <rtascollector.hpp>
@@ -36,21 +36,10 @@ namespace lsvpd {
 
 #ifdef HAVE_LIBRTAS
 
-	static bool checkRtasCall(void)
-	{
-		int fd = 0;
-		if ((fd = open(PROC_FILE_RTAS_CALL, O_RDONLY, 0)) < 0)
-			return false;
-		else {
-			close(fd);
-			return true;
-		}
-	}
-
 	/**
 	 * Based on rtas_ibm_get_vpd.c by
-	 *  @author Michael Strosaker <strosake@us.ibm.com>
-	 * 	and @author Martin Schwenke <schwenke@au1.ibm.com>
+	 * @author Michael Strosaker <strosake@us.ibm.com>
+	 * and @author Martin Schwenke <schwenke@au1.ibm.com>
 	 *
 	 * librtas_error
 	 * @brief check for any librtas specific return codes
@@ -67,7 +56,7 @@ namespace lsvpd {
 	{
 		switch (error) {
 		case RTAS_KERNEL_INT:
-		    return string("No kernel interface to firmware");
+			return string("No kernel interface to firmware");
 		case RTAS_KERNEL_IMP:
 			return string("No kernel implementation of function");
 		case RTAS_PERM:
@@ -77,7 +66,7 @@ namespace lsvpd {
 		case RTAS_NO_LOWMEM:
 			return string("Kernel out of low memory");
 		case RTAS_FREE_ERR:
-			return string("Attempt to free nonexistant RMO buffer");
+			return string("Attempt to free nonexistent RMO buffer");
 		case RTAS_TIMEOUT:
 			return string("RTAS delay exceeded specified timeout");
 		case RTAS_IO_ASSERT:
@@ -117,7 +106,7 @@ namespace lsvpd {
 	{
 		struct rtas_buf_element *head = list, *next;
 
-		while (!head) {
+		while (head) {
 			next = head->next;
 			delete head;
 			head = next;
@@ -133,14 +122,13 @@ namespace lsvpd {
 	 * @param data
 	 *   char** where we will put the vpd (*data should be NULL)
 	 */
-	int RtasCollector::rtasGetVPD(const string& yl = "",
-					char ** data = NULL)
+	unsigned long int RtasCollector::rtasGetVPD(const string& yl = "",
+				      char ** data = NULL)
 	{
-		int size = 0;
+		unsigned long int size = 0;
 		struct rtas_buf_element *current, *list;
-		char err_buf[RTAS_ERR_BUF_SIZE];
 		unsigned int seq = 1, nextSeq;
-		int num = 0, rc;
+		int rc;
 		int vpd_changed = 0;
 		char *locCode, *buf;
 
@@ -157,15 +145,17 @@ namespace lsvpd {
 
 		locCode = strdup(yl.c_str( ));
 
-		if(locCode == NULL)
+		if(locCode == NULL) {
+			deleteList(list);
 			return -ENOMEM;
+		}
 
 #ifdef DEBUGRTAS
 		printf("Collecting RTAS info: [%d] %s\n", __LINE__, __FILE__);
 #endif
 		do {
 			rc = rtas_get_vpd(locCode, current->buf, RTAS_BUF_SIZE,
-						seq, &nextSeq, &(current->size));
+					  seq, &nextSeq, &(current->size));
 
 			switch (rc) {
 			case CONTINUE:
@@ -175,6 +165,7 @@ namespace lsvpd {
 
 				if (!current->next) {
 					deleteList(list);
+					free(locCode);
 					return -ENOMEM;
 				}
 
@@ -192,24 +183,31 @@ namespace lsvpd {
 				 * for more than a threshold, we quit, than
 				 * looping forever.
 				 */
-				if (vpd_changed > VPD_CHANGED_THRESHOLD)
+				if (vpd_changed > VPD_CHANGED_THRESHOLD) {
+					free(locCode);
 					return -RTAS_ERROR;
+				}
 				seq = 1;
 				list = new rtas_buf_element;
-				if (!list)
+				if (!list) {
+					free(locCode);
 					return -ENOMEM;
+				}
 				list->size = 0;
 				list->next = NULL;
 				current = list;
 				break;
 			case PARAMETER_ERROR:
 				deleteList(list);
+				free(locCode);
 				return -RTAS_PARAMETER_ERROR;
 			case HARDWARE_ERROR:
 				deleteList(list);
+				free(locCode);
 				return -RTAS_HARDWARD_ERROR;
 			default:
 				deleteList(list);
+				free(locCode);
 				librtas_error(rc);
 				return -RTAS_ERROR;
 			}
@@ -222,14 +220,16 @@ namespace lsvpd {
 		free(locCode);
 
 		current = list;
-	        do {
+		do {
 			size += current->size;
-	        } while ((current = (current->next)) != NULL);
+		} while ((current = (current->next)) != NULL);
 
 		current = list;
 		*data = new char[ size ];
-		if( *data == NULL )
+		if( *data == NULL ) {
+			deleteList(list);
 			return -ENOMEM;
+		}
 		memset( *data, '\0', size );
 
 		buf = *data;
@@ -249,9 +249,9 @@ namespace lsvpd {
 		return string();
 	}
 
-	int RtasCollector::rtasGetVPD(const string& yl, char **data)
+	unsigned long int RtasCollector::rtasGetVPD(const string& yl, char **data)
 	{
-		return -1;
+		return -1UL;
 	}
 
 #endif
